player

package
v0.1.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package player provides a typed Go client for the player manipulation commands registered by softmod/factop/player.lua.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client provides typed methods for each player-* RCON command.

func New

func New(conn *client.Conn) *Client

New creates a player Client using the given connection.

func (*Client) Respawn

func (c *Client) Respawn(player string) (string, error)

Respawn creates a new character for a player without one. Pass empty string to respawn all connected players without characters.

func (*Client) Teleport

func (c *Client) Teleport(player string, x, y float64, surface string) (string, error)

Teleport moves a player to the given position.

Jump to