softmod

package
v0.1.18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

README

factop softmod

Lua scripts and assets injected into the Factorio save file by factop.

These files are managed by the factop service and should not be edited directly inside the save. See the project repository for documentation.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildControlLua

func BuildControlLua() (buf *bytes.Buffer, err error)

func CreateZip

func CreateZip(base string) (buffer *bytes.Buffer, err error)

Types

This section is empty.

Jump to